# Ophyd classes for pizza-box hardware

[![Build Status](https://travis-ci.com/NSLS-II/pizza-box.svg?branch=main)](https://travis-ci.com/NSLS-II/pizza-box)
[![PyPI package](https://img.shields.io/pypi/v/pizza-box.svg)](https://pypi.python.org/pypi/pizza-box)


* Free software: 3-clause BSD license
* Documentation: https://NSLS-II.github.io/pizza-box.
